function btPlotNodes(pos,tree,eplotter)
% Recursively plot all the nodes of the given binary tree 
% using the eplotter function to plot the element data 
% for each node in the current axes.
% pos is a vector of [x dx y dy] in data units
% tree is the root node of the tree to be plotted
% eplotter is a function f(pos,node.element) that plots the data in the
% element field of a node.

if isempty(tree)
    return
end

x = pos(1);
dx = pos(2);
y = pos(3);
dy = pos(4);

if ~isempty(tree.left)
    cx = x-(dx/2);
    cy = y-dy;
    line([x cx]',[y cy]','HitTest','off','Color','b');
    h = text((x+cx)/2,(y+cy)/2,'f');
    set(h,'HitTest','off','Color','b','HorizontalAlignment','right','VerticalAlignment','bottom')
    btPlotNodes([cx dx/2 cy dy],tree.left,eplotter)
end

if ~isempty(tree.right)
    cx = x+(dx/2);
    cy = y-dy;
    line([x cx]',[y cy]','HitTest','off','Color','b');
    h = text((x+cx)/2,(y+cy)/2,'b');
    set(h,'HitTest','off','Color','b','HorizontalAlignment','left','VerticalAlignment','bottom')
    btPlotNodes([cx dx/2 cy dy],tree.right,eplotter)
end

feval(eplotter,pos,tree.element)

return
